@@ -20,12 +20,18 @@ RATOM_SPACY_MODEL_MAX_LENGTH = int(
 
 # Spacy trained model names
 SPACY_MODEL_NAMES = [
+    "ca_core_news_lg",
+    "ca_core_news_md",
+    "ca_core_news_sm",
+    "ca_core_news_trf",
     "da_core_news_lg",
     "da_core_news_md",
     "da_core_news_sm",
+    "da_core_news_trf",
     "de_core_news_lg",
     "de_core_news_md",
     "de_core_news_sm",
+    "de_dep_news_trf",
     "de_pytt_bertbasecased_lg",
     "de_trf_bertbasecased_lg",
     "el_core_news_lg",
@@ -34,6 +40,7 @@ SPACY_MODEL_NAMES = [
     "en_core_web_lg",
     "en_core_web_md",
     "en_core_web_sm",
+    "en_core_web_trf",
     "en_depent_web_md",
     "en_pytt_bertbaseuncased_lg",
     "en_pytt_distilbertbaseuncased_lg",
@@ -49,19 +56,34 @@ SPACY_MODEL_NAMES = [
     "es_core_news_md",
     "es_core_news_sm",
     "es_core_web_md",
+    "es_dep_news_trf",
+    "fi_core_news_lg",
+    "fi_core_news_md",
+    "fi_core_news_sm",
     "fr_core_news_lg",
     "fr_core_news_md",
     "fr_core_news_sm",
+    "fr_dep_news_trf",
     "fr_depvec_web_lg",
+    "hr_core_news_lg",
+    "hr_core_news_md",
+    "hr_core_news_sm",
     "it_core_news_lg",
     "it_core_news_md",
     "it_core_news_sm",
     "ja_core_news_lg",
     "ja_core_news_md",
     "ja_core_news_sm",
+    "ja_core_news_trf",
+    "ko_core_news_lg",
+    "ko_core_news_md",
+    "ko_core_news_sm",
     "lt_core_news_lg",
     "lt_core_news_md",
     "lt_core_news_sm",
+    "mk_core_news_lg",
+    "mk_core_news_md",
+    "mk_core_news_sm",
     "nb_core_news_lg",
     "nb_core_news_md",
     "nb_core_news_sm",
@@ -77,10 +99,22 @@ SPACY_MODEL_NAMES = [
     "ro_core_news_lg",
     "ro_core_news_md",
     "ro_core_news_sm",
+    "ru_core_news_lg",
+    "ru_core_news_md",
+    "ru_core_news_sm",
+    "sv_core_news_lg",
+    "sv_core_news_md",
+    "sv_core_news_sm",
+    "uk_core_news_lg",
+    "uk_core_news_md",
+    "uk_core_news_sm",
+    "uk_core_news_trf",
     "xx_ent_wiki_sm",
+    "xx_sent_ud_sm",
     "zh_core_web_lg",
     "zh_core_web_md",
     "zh_core_web_sm",
+    "zh_core_web_trf",
 ]
 
 SPACY_MODELS = namedtuple("SpacyModels", SPACY_MODEL_NAMES)(*SPACY_MODEL_NAMES)
